==> magic3_1.4.0_src.tar.gz: magic3/scripts/m3/fckconfig.js <==
/*
 * デフォルトHTML編集テキストエリアの設定
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2008 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id: fckconfig.js 732 2008-06-10 10:40:57Z fishbone $
 * @link       http://www.magic3.org
 */
FCKConfig.LinkBrowser = false ;
FCKConfig.LinkDlgHideTarget		= false ;
FCKConfig.LinkDlgHideAdvanced	= true ;
FCKConfig.LinkUpload = false ;

FCKConfig.ImageBrowser = true ;
// FCKConfig.ImageBrowserURL = /* 実行時に設定 */ ;
FCKConfig.ImageDlgHideLink		= true ;
FCKConfig.ImageDlgHideAdvanced	= true ;
FCKConfig.ImageUpload = false ;

FCKConfig.FlashBrowser = true ;
// FCKConfig.FlashBrowserURL = /* 実行時に設定 */ ;
FCKConfig.FlashDlgHideAdvanced	= false ;
FCKConfig.FlashUpload = false ;

FCKConfig.TemplateReplaceAll = false ;
FCKConfig.SkinPath = FCKConfig.BasePath + 'skins/silver/' ;

// ファイルブラウザ追加
FCKConfig.Plugins.Add('FileBrowser_Thumbnail', 'en,ja', FCKConfig.BasePath + 'plugins/');

// ツールバーの設定
FCKConfig.ToolbarSets["M3Default"] = [
	['FitWindow','Source','ShowBlocks','Preview'],
	['NewPage','Templates'],
	['Cut','Copy','Paste','PasteText','PasteWord'],
	['Undo','Redo','-','Find','Replace','-','SelectAll','RemoveFormat'],
	'/',
	['Bold','Italic','Underline','StrikeThrough','-','Subscript','Superscript'],
	['OrderedList','UnorderedList','-','Outdent','Indent','Blockquote'],
	['JustifyLeft','JustifyCenter','JustifyRight','JustifyFull'],
	['Link','Unlink','Anchor'],
	['Image','Flash','Table','Rule','Smiley','SpecialChar','PageBreak'],
	'/',
	['Style','FontFormat','FontName','FontSize'],
	['TextColor','BGColor'],
	['About']
] ;

==> magic3_1.4.1_src.tar.gz: magic3/scripts/m3/fckconfig.js <==
/*
 * デフォルトHTML編集エリアの設定
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2008 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id: fckconfig.js 763 2008-06-17 10:51:41Z fishbone $
 * @link       http://www.magic3.org
 */
FCKConfig.LinkBrowser = false ;
FCKConfig.LinkDlgHideTarget		= false ;
FCKConfig.LinkDlgHideAdvanced	= true ;
FCKConfig.LinkUpload = false ;

FCKConfig.ImageBrowser = true ;
FCKConfig.ImageDlgHideLink		= true ;
FCKConfig.ImageDlgHideAdvanced	= true ;
FCKConfig.ImageUpload = false ;

FCKConfig.FlashBrowser = true ;
FCKConfig.FlashDlgHideAdvanced	= false ;
FCKConfig.FlashUpload = false ;

FCKConfig.TemplateReplaceAll = false ;
//FCKConfig.SkinPath = FCKConfig.BasePath + 'skins/silver/';
FCKConfig.SkinPath = FCKConfig.BasePath + 'skins/office2003/';

// プラグインの追加
FCKConfig.Plugins.Add('FileBrowser_Thumbnail', 'en,ja');// ファイルブラウザ
FCKConfig.Plugins.Add('Blink', 'en,ja');// 携帯用blinkタグ
FCKConfig.Plugins.Add('Marquee', 'en,ja');// 携帯用marqueeタグ
FCKConfig.Plugins.Add('Emoji', 'en,ja');// 携帯用絵文字タグ

// ツールバーの設定
// PC用
FCKConfig.ToolbarSets["M3Default"] = [
	['FitWindow','Source','ShowBlocks','Preview'],
	['NewPage','Templates'],
	['Cut','Copy','Paste','PasteText','PasteWord'],
	['Undo','Redo','-','Find','Replace','-','SelectAll','RemoveFormat'],
	'/',
	['Bold','Italic','Underline','StrikeThrough','-','Subscript','Superscript'],
	['OrderedList','UnorderedList','-','Outdent','Indent','Blockquote'],
	['JustifyLeft','JustifyCenter','JustifyRight','JustifyFull'],
	['Link','Unlink','Anchor'],
	['Image','Flash','Table','Rule','Smiley','SpecialChar','PageBreak'],
	'/',
	['Style','FontFormat','FontName','FontSize'],
	['TextColor','BGColor'],
	['About']
];
// 携帯用
FCKConfig.ToolbarSets["M3MobileDefault"] = [
	['FitWindow','Source','ShowBlocks','Preview'],
	['NewPage','Templates'],
	['Cut','Copy','Paste','PasteText','PasteWord'],
	['Undo','Redo','-','Find','Replace','-','SelectAll','RemoveFormat'],
	'/',
	['Bold','Italic','Underline','StrikeThrough','-','Subscript','Superscript','-','Blink','Marquee'],
	['OrderedList','UnorderedList','-','Outdent','Indent','Blockquote'],
	['JustifyLeft','JustifyCenter','JustifyRight','JustifyFull'],
	['Link','Unlink','Anchor'],
	['Image','Flash','Table','Rule','Smiley','SpecialChar','PageBreak'],
	'/',
	['Style','FontFormat','FontName','FontSize'],
	['TextColor','BGColor'],
	['About']
];
